# PyTorch Transformer

[![Travis](https://travis-ci.org/CyberZHG/torch-transformer.svg)](https://travis-ci.org/CyberZHG/torch-transformer)
[![Coverage](https://coveralls.io/repos/github/CyberZHG/torch-transformer/badge.svg?branch=master)](https://coveralls.io/github/CyberZHG/torch-transformer)

## Install

```bash
pip install torch-transformer
```

## Usage

```python

```
